@@ -2,8 +2,10 @@ package Sentry::Stacktrace::Frame;
 use Mojo::Base -base, -signatures;
 
 use Mojo::Home;
+use Mojo::File;
+use Sentry::SourceFileRegistry;
 
-has [qw(package filename line subroutine)];
+has [qw(module filename line subroutine)];
 has _source_file_registry => sub { Sentry::SourceFileRegistry->new };
 has _home                 => sub { Mojo::Home->new->detect };
 
@@ -17,21 +19,25 @@ sub _map_file_to_context ($self) {
     $self->line);
 }
 
+sub _relative_filename ($self) {
+  return Mojo::File::path($self->filename)->to_rel($self->_home)->to_string;
+}
+
 sub TO_JSON ($self) {
   return {
     in_app    => \($self->_is_in_app()),
     abs_path  => $self->filename,
-    file_name => 'bla',
+    file_name => $self->_relative_filename,
     lineno    => $self->line,
-    package   => $self->package,
+    module    => $self->module,
     function  => $self->subroutine,
     %{ $self->_map_file_to_context() },
   };
 }
 
-sub from_caller ($package, $pkg, $filename, $line, $subroutine, @args) {
+sub from_caller ($package, $module, $filename, $line, $subroutine, @args) {
   return $package->new({
-    package    => $pkg,
+    module     => $module,
     filename   => $filename,
     line       => $line,
     subroutine => $subroutine
